/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

/**
 * SECTION:kiba-separator
 * @short_description: Separator object on #KibaDock.
 * @see_also:#KibaWin,#KibaDock
 * @stability: Unstable
 *
 * Separator object on #KibaDock.
 */

#include <math.h>

#include "kiba-separator.h"
#include "kiba-macros.h"
#include "kiba-dock.h"

G_DEFINE_TYPE (KibaSeparator, kiba_separator, KIBA_TYPE_FIXED_OBJECT)

static void kiba_separator_class_init (KibaSeparatorClass *class) {
}

static void kiba_separator_init (KibaSeparator *separator) {
	KibaObject *object = KIBA_OBJECT(separator);
	
	SET_FLAG (object->props, KIBA_OBJECT_MOVEABLE);
	
	object->win_state = KIBA_OBJECT_WINDOW_INVISIBLE;
}

/**
 * kiba_separator_new:
 *
 * Creates and returns a KibaSeparator Instance.
 *
 * Returns: The KibaSeparator object created.
 */
GtkWidget* kiba_separator_new (const char *group) {
	GtkWidget *widget =  g_object_new (KIBA_TYPE_SEPARATOR,
                                 "group", group, NULL);
	gtk_container_add(GTK_CONTAINER(kiba_dock_get()), widget);
	return widget;	
}
